package survey_result

import (
	"surveyService/response"
	"surveyService/service/survey_result"
	"surveyService/util"
	"surveyService/util/constants"
	"surveyService/validators"

	"github.com/gin-gonic/gin"
	"gogs.uu.mdfitnesscao.com/hys/sdk"
)

// 获取详情
func Detail(c *gin.Context) {
	type Validator struct {
		ID string `json:"id" form:"id" binding:"required"`
	}
	var validator Validator
	validateErr := c.ShouldBindQuery(&validator)
	if validateErr != nil {
		response.FailValidator(c, validateErr)
		return
	}

	authMechanism, _ := util.GetFromGinContext[*sdk.AuthMechanism](c, constants.MechanismCacheKey)

	surveyResult, err := survey_result.InitMechanism(authMechanism).Detail(validator.ID)
	if err != nil {
		response.Fail(c, err)
		return
	}

	response.Success(c, map[string]any{
		"detail": survey_result.Format(surveyResult, true),
	})
}

// 获取列表
func Paginate(c *gin.Context) {
	var validator validators.SurveyResultPaginate
	validateErr := c.ShouldBindQuery(&validator)
	if validateErr != nil {
		response.FailValidator(c, validateErr)
		return
	}

	authMechanism, _ := util.GetFromGinContext[*sdk.AuthMechanism](c, constants.MechanismCacheKey)

	surveyResultList, total, err := survey_result.InitMechanism(authMechanism).Paginate(validator)
	if err != nil {
		response.Fail(c, err)
		return
	}

	var list = make([]*validators.SurveyResult, 0)
	for _, surveyResult := range surveyResultList {
		list = append(list, survey_result.Format(surveyResult, false))
	}

	response.Success(c, map[string]any{
		"list":  list,
		"total": total,
	})
}
