package validators

import "gogs.uu.mdfitnesscao.com/hys/sdk"

type Survey struct {
	ID         string `json:"id" form:"id" binding:"omitempty"`
	Name       string `json:"name" form:"name" binding:"required,min=1,max=255"`
	SurveyCode string `json:"surveyCode" form:"surveyCode" binding:"required"`
	Cover      string `json:"cover" form:"cover" binding:"omitempty,url"`
	Status     int    `json:"status" form:"-" binding:"-"`
	Remark     string `json:"remark" form:"-" binding:"-"`
	Type       int64  `json:"type" form:"type" binding:"required"`
	CreatedAt  string `json:"createdAt" form:"-" binding:"-"`
	UpdatedAt  string `json:"updatedAt" form:"-" binding:"-"`
}

type SurveyMechanism struct {
	ID                 string         `json:"id" form:"id" binding:"required"`
	AuthorizeStatus    int            `json:"authorizeStatus" form:"-" binding:"-"`
	Status             int            `json:"status" form:"-" binding:"-"`
	MechanismId        string         `json:"mechanismId" form:"mechanismId" binding:"-"`
	Mechanism          *sdk.Mechanism `json:"mechanism" form:"-" binding:"-"`
	SurveyId           string         `json:"surveyId" form:"surveyId" binding:"-"`
	Survey             *Survey        `json:"survey" form:"-" binding:"-"`
	Permissions        string         `json:"permissions" form:"-" binding:"-"`
	Name               string         `json:"name" form:"name" binding:"required,min=1,max=255"`
	Cover              string         `json:"cover" form:"cover" binding:"omitempty,url"`
	Description        string         `json:"description" form:"description" binding:"omitempty"`
	SubTitle           string         `json:"subTitle" form:"subTitle" binding:"omitempty"`
	LastVisitTime      string         `json:"lastVisitTime" form:"-" binding:"-"`      // 用户最后一次访问时间
	LastSurveyResultId string         `json:"lastSurveyResultId" form:"-" binding:"-"` // 用户最后一次答题结果ID
	CreatedAt          string         `json:"createdAt" form:"-" binding:"-"`
	UpdatedAt          string         `json:"updatedAt" form:"-" binding:"-"`
}

type SurveyResult struct {
	ID                string           `json:"id" form:"id" binding:"omitempty"`                              // 问卷结果编号（字符串）
	Method            int              `json:"method" form:"method" binding:"-"`                              // 答题方式
	StartTime         string           `json:"startTime" form:"startTime" binding:"required"`                 // 开始时间
	EndTime           string           `json:"endTime" form:"endTime" binding:"required"`                     // 结束时间
	ArchivesId        string           `json:"archivesId" form:"archivesId" binding:"required"`               // 档案ID
	Status            int              `json:"status" form:"-" binding:"-"`                                   // 状态
	Remark            string           `json:"remark" form:"-" binding:"-"`                                   // 备注
	AnswerResult      map[string]any   `json:"answerResult" form:"-" binding:"-"`                             // 答题结果
	ResultRaw         string           `json:"resultRaw" form:"-" binding:"-"`                                // 结果原始数据
	SurveyMechanismId string           `json:"surveyMechanismId" form:"surveyMechanismId" binding:"required"` // 机构问卷ID
	SurveyMechanism   *SurveyMechanism `json:"surveyMechanism" form:"-" binding:"-"`                          // 机构问卷信息
	CanAnalyze        bool             `json:"canAnalyze" form:"-" binding:"-"`                               // 是否可以分析
	CreatedAt         string           `json:"createdAt" form:"-" binding:"-"`
	UpdatedAt         string           `json:"updatedAt" form:"-" binding:"-"`
}

type SurveyResultPaginate struct {
	Page              int    `json:"page" form:"page" binding:"omitempty,min=1"`
	PageSize          int    `json:"pageSize" form:"pageSize" binding:"omitempty,min=1,max=100"`
	Method            int    `json:"method" form:"method" binding:"omitempty"`
	SurveyMechanismId string `json:"surveyMechanismId" form:"surveyMechanismId" binding:"omitempty"`
	SurveyId          string `json:"surveyId" form:"surveyId" binding:"omitempty"`
	ArchivesId        string `json:"archivesId" form:"archivesId" binding:"omitempty"`
}

type SurveyToken struct {
	Extra          string `json:"extra"`          // 第三方自定义参数
	SurveyId       string `json:"surveyId"`       // 问卷编号
	MechanismId    string `json:"mechanismId"`    // 机构编号
	SurveyResultId string `json:"surveyResultId"` // 问卷结果编号
}
